pub struct BaselineComparison {
pub added: Vec<String>,
pub modified: Vec<String>,
pub removed: Vec<String>,
}Expand description
Result of comparing a current scan against a stored baseline.
Fields
added: Vec<String>modified: Vec<String>removed: Vec<String>Trait Implementations
Sourceimpl Clone for BaselineComparison
impl Clone for BaselineComparison
Sourcefn clone(&self) -> BaselineComparison
fn clone(&self) -> BaselineComparison
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BaselineComparison
impl Debug for BaselineComparison
Sourceimpl Default for BaselineComparison
impl Default for BaselineComparison
Sourcefn default() -> BaselineComparison
fn default() -> BaselineComparison
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for BaselineComparison
impl<'de> Deserialize<'de> for BaselineComparison
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for BaselineComparison
impl PartialEq for BaselineComparison
Sourcefn eq(&self, other: &BaselineComparison) -> bool
fn eq(&self, other: &BaselineComparison) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for BaselineComparison
impl Serialize for BaselineComparison
impl StructuralPartialEq for BaselineComparison